### {{ character }} / {{ ship }}

__**Request Details:**__
**Character:** {{ character }}
**Ship:** {{ ship }}
**SRP Code:** {{ srp_code }}
**SRP Link:** {{ srp_link }}
**Request Code:** {{ request_code }}
**zKillboard Link:** {{ killboard_link }}

__**Additional Information:**__
{{ additional_info }}
